@@ -9,7 +9,7 @@ import pytz
 from dateutil.parser import parse
 from graphql_subscription_manager import SubscriptionManager
 
-from .const import RESOLUTION_HOURLY
+from .const import RESOLUTION_HOURLY, __version__
 
 DEFAULT_TIMEOUT = 15
 DEMO_TOKEN = "d1007ead2dc84a2b82f0de19451c5fb22112f7ae11d19bf2bedb224a003ff74a"
@@ -36,7 +36,7 @@ class Tibber:
 
             async def _create_session():
                 return aiohttp.ClientSession(
-                    headers={aiohttp.hdrs.USER_AGENT: "pyTibber"}
+                    headers={aiohttp.hdrs.USER_AGENT: f"pyTibber/{__version__}"}
                 )
 
             loop = asyncio.get_event_loop()
@@ -98,7 +98,9 @@ class Tibber:
                 aiohttp.hdrs.USER_AGENT, ""
             )  # will be fixed by aiohttp 4.0
             if "pyTibber" not in user_agent:
-                post_args["headers"][aiohttp.hdrs.USER_AGENT] = f"{user_agent}/pyTibber"
+                post_args["headers"][
+                    aiohttp.hdrs.USER_AGENT
+                ] = f"{user_agent} pyTibber/{__version__}"
         except Exception:  # pylint: disable=broad-except
             pass
 
@@ -212,16 +214,16 @@ class Tibber:
     async def send_notification(self, title, message):
         """Send notification."""
         query = """
-        mutation{
-          sendPushNotification(input: {
-            title: "%s",
-            message: "%s",
-          }){
+        mutation{{
+          sendPushNotification(input: {{
+            title: "{}",
+            message: "{}",
+          }}){{
             successful
             pushedToNumberOfDevices
-          }
-        }
-        """ % (
+          }}
+        }}
+        """.format(
             title,
             message,
         )
@@ -669,21 +671,21 @@ class TibberHome:
     async def get_historic_data(self, n_data, resolution=RESOLUTION_HOURLY):
         """Get historic data."""
         query = """
-                {
-                  viewer {
-                    home(id: "%s") {
-                      consumption(resolution: %s, last: %s) {
-                        nodes {
+                {{
+                  viewer {{
+                    home(id: "{}") {{
+                      consumption(resolution: {}, last: {}) {{
+                        nodes {{
                           from
                           totalCost
                           cost
                           consumption
-                        }
-                      }
-                    }
-                  }
-                }
-          """ % (
+                        }}
+                      }}
+                    }}
+                  }}
+                }}
+          """.format(
             self.home_id,
             resolution,
             n_data,
